from __future__ import unicode_literals

from django.apps import AppConfig


class RemindersConfig(AppConfig):
    name = 'glitter.reminders'
    label = 'glitter_reminders'
    verbose_name = 'reminders'
