from __future__ import unicode_literals

from django.apps import AppConfig


class PublisherConfig(AppConfig):
    name = 'glitter.publisher'
    label = 'glitter_publisher'
    verbose_name = 'Publisher'
