.related-widget-wrapper {
  width: 100%;
}
.related-widget-wrapper h2 {
  margin-top: .875em;
  text-align: center;
  font-weight: bold;
}
#container #id_image {
  width: 100%;
  background: url(../../img/select-arrow.png) center right 10px no-repeat, #fff;
  background-size: 15px;
  -webkit-appearance: none;
  -moz-appearance: none;
  display: inline;
  padding-right: 40px;
}
@media all and (min-width: 960px) {
  #container #id_image {
    width: 40%;
  }
}
#container #id_image:focus {
  outline-color: transparent;
  outline-style: none;
}
.image-file-choices {
  overflow: hidden;
}
@media all and (min-width: 421px) {
  .image-file-choices {
    display: inline;
  }
}
::-ms-expand {
  display: none;
}
.btn-holder {
  display: inline-block;
}
@media all and (min-width: 960px) {
  .btn-holder {
    display: inline-block;
  }
}
.btn-holder a {
  padding: 0 1.11111111em;
  text-decoration: none;
  color: #fff;
  border-right: 1px solid #373737;
  box-sizing: border-box;
}
.btn-holder a:last-child {
  border-right: none;
  padding-right: 0;
}
@media all and (max-width: 961px) {
  .btn-holder {
    display: block;
    margin: 0.77777778em 0;
    overflow: hidden;
  }
}
@media all and (max-width: 540px) {
  :first-child a {
    width: auto;
    max-width: auto;
  }
}
@media all and (max-width: 420px) {
  :first-child .btn-holder {
    margin: 0;
  }
  :first-child a {
    display: inline-block;
    float: left;
    width: 50%;
    max-width: 50%;
    border-right: none;
    text-align: left;
    padding: 0.27777778em 0;
    border-bottom: 1px solid #373737;
    line-height: 2.22222222em;
  }
  :first-child a:nth-child(2n -1) {
    border-right: 1px solid #373737;
  }
  :first-child a:nth-child(2n) {
    padding-left: 0.88888889em;
  }
}
.block-image-selector {
  display: block;
  position: fixed;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  overflow: auto;
  color: #fff;
  z-index: 99999999999;
  background-color: #000;
  background-color: rgba(0, 0, 0, 0.9);
  display: none;
  padding: 2.22222222em;
}
.block-image-selector .control-area {
  right: 3.5em;
  top: 3.3em;
}
.block-image-selector .inline-container {
  width: auto;
}
.block-image-selector .inline-container:first-child {
  float: left;
}
.block-image-selector .inline-container .field-container {
  display: inline-block;
  float: left;
  width: auto;
  margin-bottom: 0.55555556em;
}
.block-image-selector .inline-container .field-container input[type="search"] {
  position: relative;
  background: url(../../img/search.png) center right 10px no-repeat, #fff;
  background-size: 20px;
  border: 1px solid #000;
}
.block-image-selector select {
  padding: 0.47222222em 0.47222222em 0.47222222em 9.5 18em;
  background: #fff;
}
.block-image-selector .loader {
  background: url(../../img/loader.gif) no-repeat center #000;
  height: 100px;
  margin: 0 auto;
  width: 100px;
}
.select-wrapper {
  position: relative;
}
.select-wrapper select {
  z-index: 1;
}
.select-wrapper:before {
  display: block;
  position: absolute;
  pointer-events: none;
  content: '';
  right: 10px;
  top: 5px;
  height: 30px;
  width: 20px;
  margin: 2px;
  background: #fff;
  z-index: 5;
}
.select-wrapper:after {
  display: block;
  position: absolute;
  pointer-events: none;
  content: "";
  background-image: url(../../img/select-arrow.png);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 15px;
  right: 10px;
  top: 15px;
  height: 15px;
  width: 15px;
  z-index: 10;
}
#container select#category {
  padding-right: 40px;
}
.image-grid {
  width: 100%;
  padding: 1.11111111em;
  padding-bottom: 0;
  overflow: hidden;
  box-sizing: border-box;
  position: relative;
  z-index: 5;
}
.grid-item {
  box-sizing: border-box;
  display: block;
  float: left;
  padding: 1.11111111em;
  text-align: center;
  border: 1px solid #373737;
  border-top: 1px solid transparent;
  border-left: 1px solid transparent;
}
.grid-item .image {
  width: 100%;
  overflow: hidden;
  background: #373737;
  position: relative;
}
.grid-item .image img {
  position: absolute;
  top: 50%;
  left: 50%;
  -webkit-transform: translateX(-50%) translateY(-50%);
          transform: translateX(-50%) translateY(-50%);
  width: 100%;
  margin: auto;
}
.grid-item .image.spinner {
  background: url(../../img/loader.gif) no-repeat center #373737;
}
.grid-item h5 {
  margin-top: 0.27777778em;
  margin-bottom: 0;
  color: #fff;
  font-size: 0.77777778em;
  word-wrap: break-word;
}
.grid-item p {
  font-size: 0.77777778em;
  margin-bottom: 0;
  color: #636363;
  font-weight: 800;
}
@media all and (min-width: 960px) {
  .grid-item {
    width: 20%;
  }
  .grid-item .image {
    height: calc(20vw - 3.77777778em);
  }
  .grid-item:nth-child(5n+5) {
    border-right: 1px solid transparent;
  }
  .grid-item:nth-child(5n+1) {
    border-left: 1px solid transparent;
  }
}
@media all and (min-width: 741px) and (max-width: 960px) {
  .grid-item {
    width: 25%;
  }
  .grid-item .image {
    height: calc(25vw - 4em);
  }
  .grid-item:nth-child(4n+4) {
    border-right: 1px solid transparent;
  }
  .grid-item:nth-child(4n+1) {
    border-left: 1px solid transparent;
  }
}
@media all and (min-width: 661px) and (max-width: 740px) {
  .grid-item {
    width: 33.33333333%;
  }
  .grid-item .image {
    height: calc(33.33333333vw - 4.55555556em);
  }
  .grid-item:nth-child(3n+3) {
    border-right: 1px solid transparent;
  }
  .grid-item:nth-child(3n+1) {
    border-left: 1px solid transparent;
  }
}
@media all and (max-width: 660px) {
  .grid-item {
    width: 50%;
  }
  .grid-item .image {
    height: calc(50vw - 5.66666667em);
  }
  .grid-item:nth-child(2n+2) {
    border-right: 1px solid transparent;
  }
  .grid-item:nth-child(2n) {
    border-left: 1px solid transparent;
  }
}
@media all and (max-width: 480px) {
  .block-image-selector {
    padding: 20px;
  }
  .block-image-selector .control-area {
    position: absolute;
    right: 20px;
    top: 20px;
  }
  .image-grid {
    padding: 0;
  }
  .grid-item .image {
    height: calc(50vw - 62px);
  }
  .grid-item h5 {
    display: none;
  }
  .grid-item p {
    display: none;
  }
}
.grid-item:hover {
  border: 1px solid #fff;
}
.block-image-selector .btn-row {
  text-align: left;
  position: relative;
  top: -1px;
  text-align: center;
}
.block-image-selector .btn-row a {
  color: #fff;
}
.block-image-selector .btn-row .back {
  position: absolute;
  left: 0;
  line-height: 2.77777778em;
}
.block-image-selector .btn-row span a {
  vertical-align: center;
  line-height: 2.77777778em;
  text-decoration: none;
}
.block-image-selector .btn-row span a.active {
  color: #6d548d;
  font-weight: 800;
}
.block-image-selector .btn-row .next {
  position: absolute;
  right: 0;
  line-height: 2.77777778em;
}
.block-image-selector .btn-row,
.block-change-image .btn-row {
  border-top: 1px solid #373737;
  border-color: #373737;
  font-size: 0.88888889em;
}
.block-change-image .btn-row {
  margin-top: 1.11111111em;
  text-align: right;
}
@media all and (max-width: 480px) {
  .block-change-image .btn-row a {
    display: block;
    text-align: right;
    margin-left: 0;
    font-weight: 400;
  }
}
.btn-row.last-page .next {
  color: #373737;
  pointer-events: none;
}
.btn-row.first-page .back {
  color: #373737;
  pointer-events: none;
}
.dropzone {
  border: 2px dashed #0087F7;
  background: white;
  border-radius: 5px;
  min-height: 150px;
  padding: 54px 54px;
  margin-top: 1.875em;
}
.dropzone .dz-message {
  text-align: center;
  color: black;
}
.dropzone .dropzonePreview {
  text-align: center;
  margin-top: 20px;
}
/*# sourceMappingURL=images.css.map */