INTERVAL_2_WEEKS = 1
INTERVAL_ONE_MONTH = 2
INTERVAL_THREE_MONTHS = 3
INTERVAL_SIX_MONTHS = 4
INTERVAL_ONE_YEAR = 5
INTERVAL_CHOICES = (
    (INTERVAL_2_WEEKS, 'Every 2 weeks'),
    (INTERVAL_ONE_MONTH, 'Every month'),
    (INTERVAL_THREE_MONTHS, 'Every 3 months'),
    (INTERVAL_SIX_MONTHS, 'Every 6 months'),
    (INTERVAL_ONE_YEAR, 'Every year'),
)
