{% load static from staticfiles %}
{% load admin_urls glitter_admin_js %}
<link rel="stylesheet" href="{% static 'glitter/css/glitter.min.css' %}" />
<script src="{% jquery_min %}"></script>
<script src="{% static 'glitter/js/jquery.cookie.js' %}"></script>
<script src="{% static 'glitter/js/jquery.simplePagination.js' %}"></script>
<script src="{% static 'glitter/js/glitter_editor.js' %}"></script>
<script type="text/javascript">
    GlitterEditor.store_csrf_token("{{ csrf_token }}");
</script>
