{% extends "admin/change_form.html" %}
{% load i18n admin_urls %}

{% block object-tools %}
  {% if change %}{% if not is_popup %}
    <ul class="object-tools">
      {% block object-tools-items %}
      <li>
          {% url opts|admin_urlname:'history' original.pk|admin_urlquote as history_url %}
          <a href="{% add_preserved_filters history_url %}" class="historylink">{% trans "History" %}</a>
      </li>

      <li>
        <a href="{% url "admin:glitter_pages_page_duplicate" original.pk %}" class="viewsitelink">
          {% trans "Duplicate page" %}
        </a>
      </li>
        {% if has_absolute_url %}
          <li><a href="{{ absolute_url }}" class="viewsitelink">{% trans "View on site" %}</a></li>
        {% endif %}
      {% endblock %}
    </ul>
  {% endif %}{% endif %}
{% endblock %}
